import { createRemoteJWKSet, jwtVerify } from 'jose';
import { URL } from 'url';
import { JWTVerificationError } from './errors';
export * from './errors';
export * from './logger';
export * from './handlers';
export * from './types';
export * from './database/abstractRepository';
export * from './database/abstractDataSource';
export function parseJwtFromAuthorizationHeader(req) {
    const authorization_header = req.header('Authorization');
    if (authorization_header === undefined) {
        throw new JWTVerificationError('Authorization header is not set', 401);
    }
    const bearerTokenResult = /^Bearer (.*)$/.exec(authorization_header);
    if (bearerTokenResult === null || bearerTokenResult.length != 2) {
        throw new JWTVerificationError('Authorization header is malformed', 401);
    }
    const jwt = bearerTokenResult[1];
    if (!jwt)
        throw new JWTVerificationError('No JWT provided', 401);
    return jwt;
}
export function JWTVerify(options, validatePayload, parseJwt) {
    const jwksUrl = new URL(options.JWKS_URL);
    const JWKS = createRemoteJWKSet(jwksUrl);
    return async (req, scopes) => {
        const jwt = parseJwt(req);
        if (!jwt)
            throw new JWTVerificationError('No JWT provided', 401);
        const jwtVerifyResult = await jwtVerify(jwt, JWKS, {
            issuer: options.SECURITY_ISSUER,
            audience: options.SECURITY_AUDIENCE,
        });
        const user = jwtVerifyResult.payload;
        user.jwt = jwt;
        if (!validatePayload(user))
            throw new JWTVerificationError('Payload is malformed', 401);
        let scopeFound = false;
        for (const scope of scopes) {
            if (user.scopes.includes(scope)) {
                scopeFound = true;
                break;
            }
        }
        if (!scopeFound)
            throw new JWTVerificationError('Missing Scope: one of ' + scopes, 403);
        return user;
    };
}
//# sourceMappingURL=index.js.map